-- File: Functions.lua
-- What's for: We use this file for the functions of the addon.

local SAYKARMA_CURRENT_VERSION = GetAddOnMetadata("SayKarma", "Version"); -- get the version from the toc file (tag: #Version)
local SAYKARMA_DESCRIPTION = GetAddOnMetadata("SayKarma", "Notes"); -- get the description from the toc file (tag: #Notes)
local SayKarmaCommand = CreateFrame("Frame");

SayKarmaCommand:RegisterEvent("ADDON_LOADED");

-- Slash commands
SLASH_SAYKARMACMD1 = '/sk';
SLASH_SAYKARMACMD2 = '/saykarma';

-- Slash command: arguments dectection
function SlashCmdList.SAYKARMACMD(msg, editbox)
        -- Since there is a sensitive case detection, we put our slash commands and arguments to lowercase 
    if (msg ~= nil) then
        msg = string.lower(msg);
    end

        -- display the basic-commands
    if (msg == "help") then
        print("/sk help --------------------------------------------------");
        print("/sk en/fr: Announces will be in English or in French (/sk fr).");
        print("/sk ui: Display the window settings.");
        print("/sk version: Display the version of this addon.");
        print("/sk description: Display the description of this addon.");
        print("/sk isEnable: Check if the addon is enabled or not.");
        print("/sk reset: Reset SayKarma.");
        print("/sk enable/on: Enable SayKarma.");
        print("/sk disable/off: Disable SayKarma.");
        print("/sk legacy: Get back to the old SayKarma. Say around you that you\'ve been touched by \"Touch of Karma\" and nothing else.");
        print("/sk tab pvp/pve: Set the tab key for the nearest enemy player or for the nearest enemy.");
        print("/sk tab: Set the tab key based ou your current zone.");
        print("/sk default: Get back to the default settings.");
        print("/sk list: Display some extra commands.");
        print("-------------------------------------------------- /sk help");

        -- display some extra-commands
    elseif (msg == "list") then
        print("/sk list --------------------------------------------------");
        print("/sk dk/deathnight enable/disable: Enable/disable Death knight detection.");
        print("/sk druid/drood enable/disable: Enable/disable Druid detection.");
        print("/sk hunter/hunt enable/disable: Enable/disable Hunt detection.");
        print("/sk mage enable/disable: Enable/disable mage detection.");
        print("/sk monk/yoda enable/disable: Enable/disable Monk detection.");
        print("/sk paladin enable/disable: Enable/disable Paladin detection.");
        print("/sk priest enable/disable: Enable/disable Priest detection.");
        print("/sk rogue/rouge enable/disable: Enable/disable Rogue detection.");
        print("/sk shaman/sham enable/disable: Enable/disable Shaman detection.");
        print("/sk warlock/lock enable/disable: Enable/disable Warlock detection.");
        print("/sk warrior/war enable/disable: Enable/disable Warrior detection.");
        print("-------------------------------------------------- /sk list");

        -- change the language of the announces ("/sk en" or "/sk fr", ...)
    elseif (msg == "en") or (msg == "lang en") or (msg == "langue en") or (msg == "language en") then
        SayKarmaFunctionLanguageEn();
    
    elseif (msg == "fr") or (msg == "lang fr") or (msg == "langue fr") or (msg == "language fr") then
        SayKarmaFunctionLanguageFr();
        
        -- open the window settings
    elseif (msg == "ui") then
        InterfaceOptionsFrame_OpenToCategory(SayKarmaSettings.panel);

        -- do it a second time, since the first time it won't open the good panel (weird...)
        InterfaceOptionsFrame_OpenToCategory(SayKarmaSettings.panel);

        -- display the version on this addon
    elseif (msg == "version") then
        print("SayKarma version: " .. SAYKARMA_CURRENT_VERSION);

        -- display the description on this addon	
    elseif (msg == "description") then
        print("SayKarma\'s description :" .. SAYKARMA_DESCRIPTION);

        -- check if the addon is enable or not
    elseif (msg == "isEnable") or (msg == "isenable") then -- I know, isEnable is useless since I use string.lower() but I prefer to have a camel case 
        print("Is SayKarma enabled ?: " .. SayKarmaPrefs['SayKarmaEnable']);

        -- enable/disable SayKarma
    elseif (msg == "enable") or (msg == "on") then
        SayKarmaFunctionEnable();
    elseif (msg == "disable") or (msg == "off") then
        SayKarmaFunctionDisable();

        -- set SayKarma to the old school version or get back the new way
    elseif (msg == "legacy") then
        SayKarmaFunctionLegacy();

        -- set SayKarma with the default settings
    elseif (msg == "default") then
        SayKarmaDefaultLoadingPrefsEnable();

        -- Reset SayKarma,
    elseif (msg == "reset") or (msg == "reset yes") then
        SayKarmaResetYes();

        -- turn on/off Death knight detection	
    elseif (msg == "deathnight enable") or (msg == "dk enable") then
        SayKarmaFunctionDeathKnightEnable();
    elseif (msg == "deathnight disable") or (msg == "dk disable") then
        SayKarmaFunctionDeathKnightDisable();

        -- turn on/off Druid detection
    elseif (msg == "druid enable") or (msg == "drood enable") then
        SayKarmaFunctionDruidEnable();
    elseif (msg == "druid disable") or (msg == "drood disable") then	
        SayKarmaFunctionDruidDisable();

        -- turn on/off Hunt detection
    elseif (msg == "hunter enable") or (msg == "hunt enable") then
        SayKarmaFunctionHunterEnable();
    elseif (msg == "hunter disable") or (msg == "hunt disable") then
        SayKarmaFunctionHunterDisable();

        -- turn on/off mage detection
    elseif (msg == "mage enable") then
        SayKarmaFunctionMageEnable();
    elseif (msg == "mage disable") then
        SayKarmaFunctionMageDisable();

        -- turn on/off monk detection
    elseif (msg == "monk enable") or (msg == "yoda enable")then
        SayKarmaFunctionMonkEnable();
    elseif (msg == "monk disable") or (msg == "yoda disable") then	
        SayKarmaFunctionMonkDisable();

        -- turn on/off paladin detection
    elseif (msg == "paladin enable") then
        SayKarmaFunctionPaladinEnable();
    elseif (msg == "paladin disable") then
        SayKarmaFunctionPaladinDisable();

        -- turn on/off priest detection
    elseif (msg == "priest enable") then
        SayKarmaFunctionPriestEnable();
    elseif (msg == "priest disable") then
        SayKarmaFunctionPriestDisable();

        -- turn on/off priest detection
    elseif (msg == "rogue enable") or (msg == "rouge enable") then
        SayKarmaFunctionRogueEnable();
    elseif (msg == "rogue disable") or (msg == "rouge disable") then
        SayKarmaFunctionRogueDisable();

        -- turn on/off shaman detection
    elseif (msg == "shaman enable") or (msg == "sham enable") then
        SayKarmaFunctionShamanEnable();
    elseif (msg == "shaman disable") or (msg == "sham disable") then
        SayKarmaFunctionShamanDisable();

        -- turn on/off warlock detection
    elseif (msg == "warlock enable") or (msg == "lock enable") then
        SayKarmaFunctionWarlockEnable();
    elseif (msg == "warlock disable") or (msg == "lock disable") then
        SayKarmaFunctionWarlockDisable();

        -- turn on/off warrior detection
    elseif (msg == "warrior enable") or (msg == "war enable") then
        SayKarmaFunctionWarriorEnable();
    elseif (msg == "warrior disable") or (msg == "war disable") then
        SayKarmaFunctionWarriorDisable();

        -- use "tab" or "shift+tab" for target the nearest enemy player or the nearest ennemy
    elseif (msg == "tab pvp") then
        SayKarmaExtraSetTabPvp();
    
    elseif (msg == "tab pve") then
        SayKarmaExtraSetTabPve();
        
        -- check which mode is your tab key
    elseif (msg == "tab check") or (msg == "tabcheck") or (msg == "tab Check") or (msg == "tabCheck") or (msg == "Tabcheck") or (msg == "TabCheck") then
      if (SayKarmaTabCurrent == "pve") then
        print("SayKarma: Your tab key is set for pve");
      elseif (SayKarmaTabCurrent == "pvp") then
        print("SayKarma: Your tab key is set for pvp");
      else
        SayKarmaExtraSetTabAuto();
      end -- else
    
    -- try to set your tab key for your current zone
    elseif (msg == "tab") or (msg == "Tab") then
      SayKarmaExtraSetTabAuto();
      
    elseif (msg == "autoSet on") or (msg == "autoset on") or (msg == "autoSet enable") or (msg == "autoset enable") then
      SayKarmaFunctionTabAutoSetEnable();

    elseif (msg == "autoSet off") or (msg == "autoset off") or (msg == "autoSet disable") or (msg == "autoset disable") then
      SayKarmaFunctionTabAutoSetDisable();

    else
        -- if the user use "/sk"
        print("use /sk help for more help");
    end
    
end -- function SlashCmdList.SAYKARMACMD(msg, editbox)

-- Sets the announces in english
function SayKarmaFunctionLanguageEn()
    SayKarmaPrefs['SayKarmaLanguage'] = "en";
    print("SayKarma: Announces will be in English");
end

-- Sets the announces in french
function SayKarmaFunctionLanguageFr()
    SayKarmaPrefs['SayKarmaLanguage'] = "fr";
    print("SayKarma: Les annonces seront désormais en Français");
end

-- Enable addon, only the detection is enabled 
function SayKarmaFunctionEnable()
    SayKarmaPrefs['SayKarmaEnable'] = "yes";
    print("SayKarma enabled");
end

-- Disable addonn only the detection is disabled
function SayKarmaFunctionDisable()
    SayKarmaPrefs['SayKarmaEnable'] = "no";
    print("SayKarma disabled");
end

-- Enable auto setting your tab key based on your current zone
function SayKarmaFunctionTabAutoSetEnable()
  SayKarmaPrefs['SayKarmaAutoSetTab'] = "yes";
  print("SayKarma: auto setting enabled");
end

-- Disable auto setting your tab key based on your current zone
function SayKarmaFunctionTabAutoSetDisable()
  SayKarmaPrefs['SayKarmaAutoSetTab'] = "no";
  print("SayKarma: auto setting disabled");
end


-- Enable DeathKnight section
function SayKarmaFunctionDeathKnightEnable()
    SayKarmaPrefs['DeathKnightEnable'] = "yes";
    print("SayKarma: DeathKnight enabled");
end

-- Disable DeathKnight section
function SayKarmaFunctionDeathKnightDisable()
    SayKarmaPrefs['DeathKnightEnable'] = "no";
    print("SayKarma: DeathKnight disabled");
end

-- Enable druid section
function SayKarmaFunctionDruidEnable()
    SayKarmaPrefs['DruidEnable'] = "yes";
    print("SayKarma: Druid enabled");
end

-- Disable druid section
function SayKarmaFunctionDruidDisable()
    SayKarmaPrefs['DruidEnable'] = "no";
    print("SayKarma: Druid disabled");
end

-- Enable hunter section
function SayKarmaFunctionHunterEnable()
    SayKarmaPrefs['HunterEnable'] = "yes";
    print("SayKarma: Hunter enabled");
end

-- Disable hunter section
function SayKarmaFunctionHunterDisable()
    SayKarmaPrefs['HunterEnable'] = "no";
    print("SayKarma: Hunter disabled");
end

-- Enable mage section
function SayKarmaFunctionMageEnable()
    SayKarmaPrefs['MageEnable'] = "yes";
    print("SayKarma: Mage enabled");
end

-- Disable mage section
function SayKarmaFunctionMageDisable()
    SayKarmaPrefs['MageEnable'] = "no";
    print("SayKarma: Mage disabled");
end

-- Enable monk section
function SayKarmaFunctionMonkEnable()
    SayKarmaPrefs['MonkEnable'] = "yes";
    print("SayKarma: Monk enabled");
end

-- Disable monk section
function SayKarmaFunctionMonkDisable()
    SayKarmaPrefs['MonkEnable'] = "no";
    print("SayKarma: Monk disabled");
end

-- Enable paladin section
function SayKarmaFunctionPaladinEnable()
    SayKarmaPrefs['PaladinEnable'] = "yes";
    print("SayKarma: Paladin enabled");
end

-- Disable paladin section
function SayKarmaFunctionPaladinDisable()
    SayKarmaPrefs['PaladinEnable'] = "no";
    print("SayKarma: Paladin disabled");
end

-- Enable priest section
function SayKarmaFunctionPriestEnable()
    SayKarmaPrefs['PriestEnable'] = "yes";
    print("SayKarma: Priest enabled");
end

-- Disable priest section
function SayKarmaFunctionPriestDisable()
    SayKarmaPrefs['PriestEnable'] = "no";
    print("SayKarma: Priest disabled");
end

-- Enable rogue section
function SayKarmaFunctionRogueEnable()
    SayKarmaPrefs['RogueEnable'] = "yes";
    print("SayKarma: Rogue enabled");
end

-- Disable rogue section
function SayKarmaFunctionRogueDisable()
    SayKarmaPrefs['RogueEnable'] = "no";
    print("SayKarma: Rogue disabled");
end

-- Enable shaman section
function SayKarmaFunctionShamanEnable()
    SayKarmaPrefs['ShamanEnable'] = "yes";
    print("SayKarma: Shaman enabled");
end

-- Disable shaman section
function SayKarmaFunctionShamanDisable()
    SayKarmaPrefs['ShamanEnable'] = "no";
    print("SayKarma: Shaman disabled");
end

-- Enable warlock section
function SayKarmaFunctionWarlockEnable()
    SayKarmaPrefs['WarlockEnable'] = "yes";
    print("SayKarma: Warlock enabled");
end

-- Disable warlock section
function SayKarmaFunctionWarlockDisable()
    SayKarmaPrefs['WarlockEnable'] = "no";
    print("SayKarma: Warlock disabled");
end

-- Enable warrior section
function SayKarmaFunctionWarriorEnable()
    SayKarmaPrefs['WarriorEnable'] = "yes";
    print("SayKarma: Warrior enabled");
end

-- Disable warrior section
function SayKarmaFunctionWarriorDisable()
    SayKarmaPrefs['WarriorEnable'] = "no";
    print("SayKarma: Warrior disabled");
end

-- Enable DeathKnight Asphyxiate;
function SayKarmaFunctionDeathKnightAsphyxiateEnable()
    SayKarmaPrefs['DeathKnightAsphyxiate'] = "yes";
    print("SayKarma: DeathKnight "..GetSpellLink(108194).." enabled");
end

-- Disable DeathKnight Asphyxiate;
function SayKarmaFunctionDeathKnightAsphyxiateDisable()
    SayKarmaPrefs['DeathKnightAsphyxiate'] = "no";
    print("SayKarma: DeathKnight "..GetSpellLink(108194).." disabled");
end

-- Enable DeathKnight Mind Freeze
function SayKarmaFunctionDeathKnightMindFreezeEnable()
    SayKarmaPrefs['DeathKnightMindFreeze'] = "yes";
    print("SayKarma: DeathKnight "..GetSpellLink(47528).." enabled");
end

-- Disable DeathKnight MindFreeze
function SayKarmaFunctionDeathKnightMindFreezeDisable()
    SayKarmaPrefs['DeathKnightMindFreeze'] = "no";
    print("SayKarma: DeathKnight "..GetSpellLink(47528).." disabled");
end

-- Enable DeathKnight Strangulate
function SayKarmaFunctionDeathKnightStrangulateEnable()
    SayKarmaPrefs['DeathKnightStrangulate'] = "yes";
    print("SayKarma: DeathKnight "..GetSpellLink(47476).." enabled");
end

-- Disable DeathKnight
function SayKarmaFunctionDeathKnightStrangulateDisable()
    SayKarmaPrefs['DeathKnightStrangulate'] = "no";
    print("SayKarma: DeathKnight "..GetSpellLink(47476).." disabled");
end

-- Enable Druid Cyclone
function SayKarmaFunctionDruidCycloneEnable()
    SayKarmaPrefs['DruidCyclone'] = "yes";
    print("SayKarma: Druid "..GetSpellLink(33786).." enabled");
end

-- Disable Druid Cyclone
function SayKarmaFunctionDruidCycloneDisable()
    SayKarmaPrefs['DruidCyclone'] = "no";
    print("SayKarma: Druid "..GetSpellLink(33786).." disabled");
end

-- Enable Druid Fae Silence
function SayKarmaFunctionDruidFaeSilenceEnable()
    SayKarmaPrefs['DruidFaeSilence'] = "yes";
    print("SayKarma: Druid "..GetSpellLink(114238).." enabled");
end

-- Disable Druid Fae Silence
function SayKarmaFunctionDruidFaeSilenceDisable()
    SayKarmaPrefs['DruidFaeSilence'] = "no";
    print("SayKarma: Druid "..GetSpellLink(114238).." disabled");
end

-- Enable Druid Rake
function SayKarmaFunctionDruidRakeEnable()
    SayKarmaPrefs['DruidRake'] = "yes";
    print("SayKarma: Druid "..GetSpellLink(1822).." enabled");
end

-- Disable Druid Rake
function SayKarmaFunctionDruidRakeDisable()
    SayKarmaPrefs['DruidRake'] = "no";
    print("SayKarma: Druid "..GetSpellLink(1822).." disabled");
end

-- Enable Druid Skull Bash
function SayKarmaFunctionDruidSkullBashEnable()
    SayKarmaPrefs['DruidSkullBash'] = "yes";
    print("SayKarma: Druid "..GetSpellLink(106839).." enabled");
end

-- Disable Druid Skull Bash
function SayKarmaFunctionDruidSkullBashDisable()
    SayKarmaPrefs['DruidSkullBash'] = "no";
    print("SayKarma: Druid "..GetSpellLink(106839).." disabled");
end

-- Enable Hunt Counter Shot
function SayKarmaFunctionHunterCounterShotEnable()
    SayKarmaPrefs['HunterCounterShot'] = "yes";
    print("SayKarma: Hunter "..GetSpellLink(147362).." enabled");
end

-- Disable Hunt Counter Shot
function SayKarmaFunctionHunterCounterShotDisable()
    SayKarmaPrefs['HunterCounterShot'] = "no";
    print("SayKarma: Hunter "..GetSpellLink(147362).." disabled");
end

-- Enable Hunt Freezing Trap
function SayKarmaFunctionHunterFreezingTrapEnable()
    SayKarmaPrefs['HunterFreezingTrap'] = "yes";
    print("SayKarma: Hunter "..GetSpellLink(3355).." enabled");
end

-- Disable Hunt Freezing Trap
function SayKarmaFunctionHunterFreezingTrapDisable()
    SayKarmaPrefs['HunterFreezingTrap'] = "no";
    print("SayKarma: Hunter "..GetSpellLink(3355).." disabled");
end

-- Enable Hunt Silencing Shot
function SayKarmaFunctionHunterSilencingShotEnable()
    SayKarmaPrefs['HunterSilencingShot'] = "yes";
    print("SayKarma: Hunter "..GetSpellLink(41084).." enabled");
end

-- Disable Hunt Silencing Shot
function SayKarmaFunctionHunterSilencingShotDisable()
    SayKarmaPrefs['HunterSilencingShot'] = "no";
    print("SayKarma: Hunter "..GetSpellLink(41084).." disabled");
end

-- Enable Hunt Wyvern Sting
function SayKarmaFunctionHunterWyvernStingEnable()
    SayKarmaPrefs['HunterWyvernSting'] = "yes";
    print("SayKarma: Hunter "..GetSpellLink(19386).." enabled");
end

-- Enable Hunt Wyvern Sting
function SayKarmaFunctionHunterWyvernStingDisable()
    SayKarmaPrefs['HunterWyvernSting'] = "yes";
    print("SayKarma: Hunter "..GetSpellLink(19386).." disabled");
end

-- Enable Mage Counterspell
function SayKarmaFunctionMageCounterspellEnable()
    SayKarmaPrefs['MageCounterspell'] = "yes";
    print("SayKarma: Mage "..GetSpellLink(2139).." enabled");
end

-- Disable Mage Counterspell
function SayKarmaFunctionMageCounterspellDisable()
    SayKarmaPrefs['MageCounterspell'] = "no";
    print("SayKarma: Mage "..GetSpellLink(2139).." disabled");
end

-- Enable Mage Deep Freeze
function SayKarmaFunctionMageDeepFreezeEnable()
    SayKarmaPrefs['MageDeepFreeze'] = "yes";
    print("SayKarma: Mage "..GetSpellLink(44572).." enabled");
end

-- Disable Mage Deep Freeze
function SayKarmaFunctionMageDeepFreezeDisable()
    SayKarmaPrefs['MageDeepFreeze'] = "no";
    print("SayKarma: Mage "..GetSpellLink(44572).." disabled");
end

-- Enable Mage Dragon's Breath
function SayKarmaFunctionMageDragonsBreathEnable()
	SayKarmaPrefs['MageDragonsBreath'] = "yes"
	print("SayKarma: Mage "..GetSpellLink(31661).." enabled");
end

-- Disable Mage Dragon's Breath
function SayKarmaFunctionMageDragonsBreathDisable()
	SayKarmaPrefs['MageDragonsBreath'] = "no"
	print("SayKarma: Mage "..GetSpellLink(31661).." disabled");
end

-- Enable Mage Frostjaw
function SayKarmaFunctionMageFrostjawEnable()
    SayKarmaPrefs['MageFrostjaw'] = "yes";
    print("SayKarma: Mage "..GetSpellLink(102051).." enabled");
end

-- Disable Mage Frostjaw
function SayKarmaFunctionMageFrostjawDisable()
    SayKarmaPrefs['MageFrostjaw'] = "no";
    print("SayKarma: Mage "..GetSpellLink(102051).." disabled");
end

-- Enable Mage Polymorph
function SayKarmaFunctionMagePolymorphEnable()
    -- Keep in mind, the ui check only ['MagePolymorphSheep']
    -- we if we add a way to change only one of them, we should change the code
    -- in the Setting.lua file section: CheckButton enable Mage Polymorph
    SayKarmaPrefs['MagePolymorphBlackCat'] = "yes";
    SayKarmaPrefs['MagePolymorphMonkey'] = "yes";
    SayKarmaPrefs['MagePolymorphPeacock'] = "yes";
    SayKarmaPrefs['MagePolymorphPenguin'] = "yes";
    SayKarmaPrefs['MagePolymorphPolarBearCub'] = "yes";
    SayKarmaPrefs['MagePolymorphPig'] = "yes";
    SayKarmaPrefs['MagePolymorphRabbit'] = "yes";
    SayKarmaPrefs['MagePolymorphSheep'] = "yes";
    SayKarmaPrefs['MagePolymorphTurkey'] = "yes";
    SayKarmaPrefs['MagePolymorphTurtle'] = "yes";
    print("SayKarma: Mage "..GetSpellLink(61305).." (Black Cat) enabled");          -- Black Cat
    print("SayKarma: Mage "..GetSpellLink(161354).." (Monkey) enabled");            -- Monkey
    print("SayKarma: Mage "..GetSpellLink(161372).." (Peacok) enabled");            -- Peacock
    print("SayKarma: Mage "..GetSpellLink(161355).." (Penguin) enabled");           -- Penguin
    print("SayKarma: Mage "..GetSpellLink(161353).." (Polar Bear Cub) enabled");    -- Polar Bear Cub
    print("SayKarma: Mage "..GetSpellLink(28272).." (Pig) enabled");                -- Pig
    print("SayKarma: Mage "..GetSpellLink(61721).." (Rabbit) enabled");             -- Rabbit
    print("SayKarma: Mage "..GetSpellLink(118).." (Sheep) enabled");                -- Sheep
    print("SayKarma: Mage "..GetSpellLink(61780).." (Turkey) enabled");             -- Turkey
    print("SayKarma: Mage "..GetSpellLink(28271).." (Turtle) enabled");             -- Turtle
end

-- Disable Mage Polymorph
function SayKarmaFunctionMagePolymorphDisable()
    -- Keep in mind, the ui check only ['MagePolymorphSheep']
    -- we if we add a way to change only one of them, we should change the code
    -- in the Setting.lua file section: CheckButton enable Mage Polymorph
    SayKarmaPrefs['MagePolymorphBlackCat'] = "no";
    SayKarmaPrefs['MagePolymorphMonkey'] = "no";
    SayKarmaPrefs['MagePolymorphPeacock'] = "no";
    SayKarmaPrefs['MagePolymorphPenguin'] = "no";
    SayKarmaPrefs['MagePolymorphPolarBearCub'] = "no";
    SayKarmaPrefs['MagePolymorphPig'] = "no";
    SayKarmaPrefs['MagePolymorphRabbit'] = "no";
    SayKarmaPrefs['MagePolymorphSheep'] = "no";
    SayKarmaPrefs['MagePolymorphTurkey'] = "no";
    SayKarmaPrefs['MagePolymorphTurtle'] = "no";
    print("SayKarma: Mage "..GetSpellLink(61305).." (Black Cat) disabled");         -- Black Cat
    print("SayKarma: Mage "..GetSpellLink(161354).." (Monkey) disabled");           -- Monkey
    print("SayKarma: Mage "..GetSpellLink(161372).." (Peacok) disabled");           -- Peacock
    print("SayKarma: Mage "..GetSpellLink(161355).." (Penguin) disabled");          -- Penguin
    print("SayKarma: Mage "..GetSpellLink(161353).." (Polar Bear Cub) disabled");   -- Polar Bear Cub
    print("SayKarma: Mage "..GetSpellLink(28272).." (Pig) disabled");               -- Pig
    print("SayKarma: Mage "..GetSpellLink(61721).." (Rabbit) disabled");            -- Rabbit
    print("SayKarma: Mage "..GetSpellLink(118).." (Sheep) disabled");               -- Sheep
    print("SayKarma: Mage "..GetSpellLink(61780).." (Turkey) disabled");            -- Turkey
    print("SayKarma: Mage "..GetSpellLink(28271).." (Turtle) disabled");            -- Turtle
end

-- Enable Monk Leg Sweep
function SayKarmaFunctionMonkLegSweepEnable()
    SayKarmaPrefs['MonkLegSweep'] = "yes";
    print("SayKarma: Monk "..GetSpellLink(119381).." enabled");
end

-- Disable Monk Leg Sweep
function SayKarmaFunctionMonkLegSweepDisable()
    SayKarmaPrefs['MonkLegSweep'] = "no";
    print("SayKarma: Monk "..GetSpellLink(119381).." disabled");
end

-- Enable Monk Paralysis
function SayKarmaFunctionMonkParalysisEnable()
    SayKarmaPrefs['MonkParalysis'] = "yes";
    print("SayKarma: Monk "..GetSpellLink(115078).." enabled");
end

-- Disable Monk Paralysis
function SayKarmaFunctionMonkParalysisDisable()
    SayKarmaPrefs['MonkParalysis'] = "no";
    print("SayKarma: Monk "..GetSpellLink(115078).." disabled");
end

-- Enable Monk Spear Hand Strike
function SayKarmaFunctionMonkSpearHandStrikeEnable()
    SayKarmaPrefs['MonkSpearHandStrike'] = "yes";
    print("SayKarma: Monk "..GetSpellLink(116705).." enabled");
end

-- Disable Monk Spear Hand Strike
function SayKarmaFunctionMonkSpearHandStrikeDisable()
    SayKarmaPrefs['MonkSpearHandStrike'] = "no";
    print("SayKarma: Monk "..GetSpellLink(116705).." disabled");
end

-- Enable Monk Touch Of Karma
function SayKarmaFunctionMonkTouchOfKarmaEnable()
    SayKarmaPrefs['MonkTouchOfKarma'] = "yes";
    print("SayKarma: Monk "..GetSpellLink(122470).." enabled");
end

-- Disable Monk Touch Of Karma
function SayKarmaFunctionMonkTouchOfKarmaDisable()
    SayKarmaPrefs['MonkTouchOfKarma'] = "no";
    print("SayKarma: Monk "..GetSpellLink(122470).." disabled");
end

-- Enable Paladin Fist Of Justice
function SayKarmaFunctionPaladinFistOfJusticeEnable()
    SayKarmaPrefs['PaladinFistOfJustice'] = "yes";
    print("SayKarma: Paladin "..GetSpellLink(105593).." enabled");
end

-- Disable Paladin Fist Of Justice
function SayKarmaFunctionPaladinFistOfJusticeDisable()
    SayKarmaPrefs['PaladinFistOfJustice'] = "no";
    print("SayKarma: Paladin "..GetSpellLink(105593).." disabled");
end

-- Enable Paladin Hammer Of Justice
function SayKarmaFunctionPaladinHammerOfJusticeEnable()
    SayKarmaPrefs['PaladinHammerOfJustice'] = "yes";
    print("SayKarma: Paladin "..GetSpellLink(853).." enabled");
end

-- Disable Paladin Hammer Of Justice
function SayKarmaFunctionPaladinHammerOfJusticeDisable()
    SayKarmaPrefs['PaladinHammerOfJustice'] = "no";
    print("SayKarma: Paladin "..GetSpellLink(853).." disabled");
end

-- Enable Paladin Rebuke
function SayKarmaFunctionPaladinRebukeEnable()
    SayKarmaPrefs['PaladinRebuke'] = "yes";
    print("SayKarma: Paladin "..GetSpellLink(96231).." enabled");
end

-- Disable Paladin Rebuke
function SayKarmaFunctionPaladinRebukeDisable()
    SayKarmaPrefs['PaladinRebuke'] = "no";
    print("SayKarma: Paladin "..GetSpellLink(96231).." disabled");
end

-- Enable Paladin Repentance
function SayKarmaFunctionPaladinRepentanceEnable()
    SayKarmaPrefs['PaladinRepentance'] = "yes";
    print("SayKarma: Paladin "..GetSpellLink(20066).." enabled");
end

-- Disable Paladin Repentance
function SayKarmaFunctionPaladinRepentanceDisable()
    SayKarmaPrefs['PaladinRepentance'] = "no";
    print("SayKarma: Paladin "..GetSpellLink(20066).." disabled");
end

-- Enable Priest Dominate Mind
function SayKarmaFunctionPriestDominateMindEnable()
    SayKarmaPrefs['PriestDominateMind'] = "yes";
    print("SayKarma: Priest "..GetSpellLink(605).." enabled");
end

-- Disable Priest Dominate Mind
function SayKarmaFunctionPriestDominateMindDisable()
    SayKarmaPrefs['PriestDominateMind'] = "no";
    print("SayKarma: Priest "..GetSpellLink(605).." disabled");
end

-- Enable Priest Holy Word Chastise
function SayKarmaFunctionPriestHolyWordChastiseEnable()
    SayKarmaPrefs['PriestHolyWordChastise'] = "yes";
    print("SayKarma: Priest "..GetSpellLink(88625).." enabled");
end

-- Disable Priest Holy Word Chastise
function SayKarmaFunctionPriestHolyWordChastiseDisable()
    SayKarmaPrefs['PriestHolyWordChastise'] = "no";
    print("SayKarma: Priest "..GetSpellLink(88625).." disabled");
end

-- Enable Priest Psychic Horror
function SayKarmaFunctionPriestPsychicHorrorEnable()
    SayKarmaPrefs['PriestPsychicHorror'] = "yes";
    print("SayKarma: Priest "..GetSpellLink(64044).." enabled");
end

-- Disable Priest Psychic Horror
function SayKarmaFunctionPriestPsychicHorrorDisable()
    SayKarmaPrefs['PriestPsychicHorror'] = "no";
    print("SayKarma: Priest "..GetSpellLink(64044).." disabled");
end

-- Enable Priest Silence
function SayKarmaFunctionPriestSilenceEnable()
    SayKarmaPrefs['PriestSilence'] = "yes";
    print("SayKarma: Priest "..GetSpellLink(15487).." enabled");
end

-- Disable Priest Silence
function SayKarmaFunctionPriestSilenceDisable()
    SayKarmaPrefs['PriestSilence'] = "no";
    print("SayKarma: Priest "..GetSpellLink(15487).." disabled");
end

-- Enable Rogue Blind
function SayKarmaFunctionRogueBlindEnable()
    SayKarmaPrefs['RogueBlind'] = "yes";
    print("SayKarma: Rogue "..GetSpellLink(2094).." enabled");
end

-- Disable Rogue Blind
function SayKarmaFunctionRogueBlindDisable()
    SayKarmaPrefs['RogueBlind'] = "no";
    print("SayKarma: Rogue "..GetSpellLink(2094).." disabled");
end

-- Enable Rogue Garrote
function SayKarmaFunctionRogueGarroteEnable()
    SayKarmaPrefs['RogueGarrote'] = "yes";
    print("SayKarma: Rogue "..GetSpellLink(703).." & "..GetSpellLink(1330).." enabled");
end

-- Disable Rogue Garrote
function SayKarmaFunctionRogueGarroteDisable()
    SayKarmaPrefs['RogueGarrote'] = "no";
    print("SayKarma: Rogue "..GetSpellLink(703).." & "..GetSpellLink(1330).." disabled");
end

-- Enable Rogue kick
function SayKarmaFunctionRoguekickEnable()
    SayKarmaPrefs['Roguekick'] = "yes";
    print("SayKarma: Rogue "..GetSpellLink(1766).." enabled");
end

-- Disable Rogue kick
function SayKarmaFunctionRoguekickDisable()
    SayKarmaPrefs['Roguekick'] = "no";
    print("SayKarma: Rogue "..GetSpellLink(1766).." disabled");
end

-- Enable Rogue Sap
function SayKarmaFunctionRogueSapEnable()
    SayKarmaPrefs['RogueSap'] = "yes";
    print("SayKarma: Rogue "..GetSpellLink(6770).." enabled");
end

-- Disable Rogue Sap
function SayKarmaFunctionRogueSapDisable()
    SayKarmaPrefs['RogueSap'] = "no";
    print("SayKarma: Rogue "..GetSpellLink(6770).." disabled");
end

-- Enable Shaman Hex
function SayKarmaFunctionShamanHexEnable()
    SayKarmaPrefs['ShamanHex'] = "yes";
    print("SayKarma: Shaman "..GetSpellLink(51514).." enabled");
end

-- Disable Shaman Hex
function SayKarmaFunctionShamanHexDisable()
    SayKarmaPrefs['ShamanHex'] = "no";
    print("SayKarma: Shaman "..GetSpellLink(51514).." disabled");
end

-- Enable Shaman Wind Shear
function SayKarmaFunctionShamanWindShearEnable()
    SayKarmaPrefs['ShamanWindShear'] = "yes";
    print("SayKarma: Shaman "..GetSpellLink(57994).." enabled");
end

-- Disable Shaman Wind Shear
function SayKarmaFunctionShamanWindShearDisable()
    SayKarmaPrefs['ShamanWindShear'] = "no";
    print("SayKarma: Shaman "..GetSpellLink(57994).." disabled");
end

-- Enable Warlock Mesmerize
function SayKarmaFunctionWarlockMesmerizeSeductionEnable()
    SayKarmaPrefs['WarlockMesmerize'] = "yes";
    SayKarmaPrefs['WarlockSeduction'] = "yes";
    print("SayKarma: Warlock "..GetSpellLink(115268).." & "..GetSpellLink(6358).." enabled");
end

-- Disable Warlock Mesmerize
function SayKarmaFunctionWarlockMesmerizeSeductionDisable()
    SayKarmaPrefs['WarlockMesmerize'] = "no";
    SayKarmaPrefs['WarlockSeduction'] = "no";
    print("SayKarma: Warlock "..GetSpellLink(115268).." & "..GetSpellLink(6358).." disabled");
end

-- Enable Warlock SpellLock
function SayKarmaFunctionWarlockSpellLockEnable()
    SayKarmaPrefs['WarlockSpellLock'] = "yes";
    print("SayKarma: Warlock "..GetSpellLink(19647).." enabled");
end

-- Disable Warlock SpellLock
function SayKarmaFunctionWarlockSpellLockDisable()
    SayKarmaPrefs['WarlockSpellLock'] = "no";
    print("SayKarma: Warlock "..GetSpellLink(19647).." disabled");
end

-- Enable Warrior Dragon Roar
function SayKarmaFunctionWarriorDragonRoarEnable()
    SayKarmaPrefs['WarriorDragonRoar'] = "yes";
    print("SayKarma: Warrior "..GetSpellLink(118000).." enabled");
end

-- Disable Warrior Dragon Roar
function SayKarmaFunctionWarriorDragonRoarDisable()
    SayKarmaPrefs['WarriorDragonRoar'] = "no";
    print("SayKarma: Warrior "..GetSpellLink(118000).." disabled");
end

-- Enable Warrior Pummel
function SayKarmaFunctionWarriorPummelEnable()
    SayKarmaPrefs['WarriorPummel'] = "yes";
    print("SayKarma: Warrior "..GetSpellLink(6552).." enabled");
end

-- Disable Warrior Pummel
function SayKarmaFunctionWarriorPummelDisable()
    SayKarmaPrefs['WarriorPummel'] = "no";
    print("SayKarma: Warrior "..GetSpellLink(6552).." disabled");
end

-- Enable Warrior Shockwave
function SayKarmaFunctionWarriorShockwaveEnable()
    SayKarmaPrefs['WarriorShockwave'] = "yes";
    print("SayKarma: Warrior "..GetSpellLink(132168).." enabled");
end

-- Disable Warrior Shockwave
function SayKarmaFunctionWarriorShockwaveDisable()
    SayKarmaPrefs['WarriorShockwave'] = "no";
    print("SayKarma: Warrior "..GetSpellLink(132168).." disabled");
end

-- Enable Warrior Storm Bolt
function SayKarmaFunctionWarriorStormBoltEnable()
    SayKarmaPrefs['WarriorStormBolt'] = "yes";
    SayKarmaPrefs['WarriorStormBoltOffHand'] = "yes";
    print("SayKarma: Warrior "..GetSpellLink(107570).." enabled");
end

-- Disable Warrior Storm Bolt
function SayKarmaFunctionWarriorStormBoltDisable()
    SayKarmaPrefs['WarriorStormBolt'] = "no";
    SayKarmaPrefs['WarriorStormBoltOffHand'] = "no";
    print("SayKarma: Warrior "..GetSpellLink(107570).." disabled");
end

-- Reset SayKarma, everything has to be reset
function SayKarmaResetYes()
    print("SayKarma: reset in progress");
    SAYKARMA_VERSION = nil;
    SayKarmaPrefs = nil;

    SAYKARMA_VERSION = SAYKARMA_CURRENT_VERSION;
    print("SayKarma: loading default values");
    SayKarmaDefaultLoadingPrefsEnable();
    print("SayKarma: reseted");
end

-- Set SayKarma to the old SayKarma, meaning, say arround you only if you were touched bye "Touch of Karma" and nothing else
function SayKarmaFunctionLegacy()
    -- we disable everything
    SayKarmaDefaultLoadingPrefsDisable();

    -- we enable only what we need
    SayKarmaPrefs['SayKarmaEnable'] = "yes";
    SayKarmaPrefs['DecorationEnable'] = "yes";
    SayKarmaPrefs['WhichDecoration'] = "Skull";
    SayKarmaPrefs['MonkEnable'] = "yes";
    SayKarmaPrefs['MonkTouchOfKarma'] = "yes";

    print("SayKarma \"Legacy\" mode avativated");
end

-- Loading
function SayKarmaCommand:OnEvent(event)
  -- when addons are loaded
    if (event == "ADDON_LOADED") then
        -- initialization
        if (SAYKARMA_VERSION == nil) then
            SAYKARMA_VERSION = SAYKARMA_CURRENT_VERSION;
        end

        if (SayKarmaPrefs == nil) then
            print("Initialization");
            SayKarmaDefaultLoadingPrefsEnable();
        end
        -- initialization over

        -- is the user had an old version ? check if we have to update some old variables
        if (SAYKARMA_VERSION ~= SAYKARMA_CURRENT_VERSION) then
            -- we clean everything
            print("Updating saved variables...");
            SayKarmaFunctionUpdateSavedVariables();
            print("Updating terminated");
        end

        -- just a simple text to make the user aware that everything is loaded and and how to use the addon
        if (SayKarmaVarTmp == nil) then
            SayKarmaVarTmp = 1;
            print("SayKarma Loaded - use \'/sk help\' for more help");
        end
          
          

    end -- ((event == "ADDON_LOADED")
end -- function SayKarmaCommand:OnEvent


-- Allow to update some saved variables Just in case
function SayKarmaFunctionUpdateSavedVariables()
    SAYKARMA_VERSION = SAYKARMA_CURRENT_VERSION;
    SayKarmaPrefs = nil;	-- reset

    -- get back with the default settings
    SayKarmaDefaultLoadingPrefsEnable();
end

-- put SayKarma with the default mode, everything is enabled
function SayKarmaDefaultLoadingPrefsEnable()
    -- let's go to enable everything
    -- I know ! I could use some booleans instead of string variables with "yes"/"no"
    -- But I don't like Booleans, besides, I do what I want 
    SayKarmaPrefs = {		-- turn on all prefs
        ['SayKarmaEnable'] = "yes",
        ['SayKarmaLanguage'] = "en",
        ['SayKarmaAutoSetTab'] = "yes",
        ['SayKarmaTabMode'] = "unknown",
        ['DecorationEnable'] = "yes",
        ['WhichDecoration'] = "Skull",
        ['DeathKnightEnable'] = "yes",
        ['DruidEnable'] = "yes",
        ['HunterEnable'] = "yes",
        ['MageEnable'] = "yes",
        ['MonkEnable'] = "yes",
        ['PaladinEnable'] = "yes",
        ['PriestEnable'] = "yes",
        ['RogueEnable'] = "yes",
        ['ShamanEnable'] = "yes",
        ['WarlockEnable'] = "yes",
        ['WarriorEnable'] = "yes",
        ['DeathKnightAsphyxiate'] = "yes",
        ['DeathKnightMindFreeze'] = "yes",
        ['DeathKnightStrangulate'] = "yes",
        ['DruidCyclone'] = "yes",
        ['DruidFaeSilence'] = "yes",
        ['DruidRake'] = "yes",
        ['DruidSkullBash'] = "yes",
        ['HunterCounterShot'] = "yes",
        ['HunterFreezingTrap'] = "yes",
        ['HunterSilencingShot'] = "yes",
        ['HunterWyvernSting'] = "yes",
        ['MageCounterspell'] = "yes",
        ['MageDeepFreeze'] = "yes",
        ['MageDragonsBreath'] = "yes",
        ['MageFrostjaw'] = "yes",
        ['MagePolymorphBlackCat'] = "yes",
        ['MagePolymorphMonkey'] = "yes",
        ['MagePolymorphPeacock'] = "yes",
        ['MagePolymorphPenguin'] = "yes",
        ['MagePolymorphPolarBearCub'] = "yes",
        ['MagePolymorphPig'] = "yes",
        ['MagePolymorphRabbit'] = "yes",
        ['MagePolymorphSheep'] = "yes",
        ['MagePolymorphTurkey'] = "yes",
        ['MagePolymorphTurtle'] = "yes",
        ['MonkLegSweep'] = "yes",
        ['MonkParalysis'] = "yes",
        ['MonkSpearHandStrike'] = "yes",
        ['MonkTouchOfKarma'] = "yes",
        ['PaladinFistOfJustice'] = "yes",
        ['PaladinHammerOfJustice'] = "yes",
        ['PaladinRebuke'] = "yes",
        ['PaladinRepentance'] = "yes",
        ['PriestDominateMind'] = "yes",
        ['PriestHolyWordChastise'] = "yes",
        ['PriestPsychicHorror'] = "yes",
        ['PriestSilence'] = "yes",
        ['RogueBlind'] = "yes",
        ['RogueGarrote'] = "yes",
        ['Roguekick'] = "yes",
        ['RogueSap'] = "yes",
        ['ShamanHex'] = "yes",
        ['ShamanWindShear'] = "yes",
        ['WarlockMesmerize'] = "yes",
        ['WarlockSeduction'] = "yes",
        ['WarlockSpellLock'] = "yes",
        ['WarriorDragonRoar'] = 'yes',
        ['WarriorPummel'] = "yes",
        ['WarriorShockwave'] = "yes",
        ['WarriorStormBolt'] = "yes",
        ['WarriorStormBoltOffHand'] = "yes",
    };

    print("SayKarma \"Default\" mode activated");
end

-- turn off SayKarma, everything is disabled
function SayKarmaDefaultLoadingPrefsDisable()
    -- let's go to disable everything
    SayKarmaPrefs = {			-- turn off all prefs
        ['SayKarmaEnable'] = "no",
        ['SayKarmaLanguage'] = "en",
        ['SayKarmaAutoSetTab'] = "no",
        ['SayKarmaTabMode'] = "unknown",
        ['DecorationEnable'] = "no",
        ['WhichDecoration'] = "Skull",
        ['DeathKnightEnable'] = "no",
        ['DruidEnable'] = "no",
        ['HunterEnable'] = "no",
        ['MageEnable'] = "no",
        ['MonkEnable'] = "no",
        ['PaladinEnable'] = "no",
        ['PriestEnable'] = "no",
        ['RogueEnable'] = "no",
        ['ShamanEnable'] = "no",
        ['WarlockEnable'] = "no",
        ['WarriorEnable'] = "no",
        ['DeathKnightAsphyxiate'] = "no",
        ['DeathKnightMindFreeze'] = "no",
        ['DeathKnightStrangulate'] = "no",
        ['DruidCyclone'] = "no",
        ['DruidFaeSilence'] = "no",
        ['DruidRake'] = "no",
        ['DruidSkullBash'] = "no",
        ['HunterCounterShot'] = "no",
        ['HunterFreezingTrap'] = "no",
        ['HunterSilencingShot'] = "no",
        ['HunterWyvernSting'] = "yes",
        ['MageCounterspell'] = "no",
        ['MageDeepFreeze'] = "no",
        ['MageDragonsBreath'] = "no",
        ['MageFrostjaw'] = "no",
        ['MagePolymorphBlackCat'] = "no",
        ['MagePolymorphPenguin'] = "no",
        ['MagePolymorphPolarBearCub'] = "no",
        ['MagePolymorphMonkey'] = "no",
        ['MagePolymorphPeacock'] = "no",
        ['MagePolymorphPig'] = "no",
        ['MagePolymorphRabbit'] = "no",
        ['MagePolymorphSheep'] = "no",
        ['MagePolymorphTurkey'] = "no",
        ['MagePolymorphTurtle'] = "no",
        ['MonkLegSweep'] = "no",
        ['MonkParalysis'] = "no",
        ['MonkSpearHandStrike'] = "no",
        ['MonkTouchOfKarma'] = "no",
        ['PaladinFistOfJustice'] = "no",
        ['PaladinHammerOfJustice'] = "no",
        ['PaladinRebuke'] = "no",
        ['PaladinRepentance'] = "no",
        ['PriestDominateMind'] = "no",
        ['PriestHolyWordChastise'] = "no",
        ['PriestPsychicHorror'] = "no",
        ['PriestSilence'] = "no",
        ['RogueBlind'] = "no",
        ['RogueGarrote'] = "no",
        ['Roguekick'] = "no",
        ['RogueSap'] = "no",
        ['ShamanHex'] = "no",
        ['ShamanWindShear'] = "no",
        ['WarlockMesmerize'] = "no",
        ['WarlockSeduction'] = "no",
        ['WarlockSpellLock'] = "no",
        ['WarriorDragonRoar'] = 'no',
        ['WarriorPummel'] = "no",
        ['WarriorShockwave'] = "no",
        ['WarriorStormBolt'] = "no",
        ['WarriorStormBoltOffHand'] = "no",
    };
end

function SayKarmaExtraSetTabPvp()
    if UnitAffectingCombat("player") then
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
            print("SayKarma: Error ! You are in combat");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            print("SayKarma: Erreur ! Vous êtes en combat");
        end
        return
    else
        SetBinding("TAB", "TARGETNEARESTENEMYPLAYER");
        SetBinding("SHIFT-TAB", "TARGETNEARESTENEMY");
        SayKarmaPrefs['SayKarmaTabMode'] = "pvp";
        
        SayKarmaTabCurrent = "pvp";
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
            print("SayKarma: Now the Tab key is for pvp mode. Use \"Tab\" for target the nearest enemy player and \"Shift+Tab\" for target the nearest enemy");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            print("SayKarma: Désormais la touche Tabulation est en mode pvp. Utiliser \"Tab\" pour cibler le joueur ennemi le plus proche et \"Shift+Tab\" pour tout ennemi.");
        end
    end
end

function SayKarmaExtraSetTabPve()
    if UnitAffectingCombat("player") then
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
            print("SayKarma: Error ! You are in combat");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            print("SayKarma: Erreur ! Vous êtes en combat");
        end
        return
    else
        SetBinding("TAB", "TARGETNEARESTENEMY");
        SetBinding("SHIFT-TAB", "TARGETNEARESTENEMYPLAYER");
        SayKarmaPrefs['SayKarmaTabMode'] = "pve";
        
        SayKarmaTabCurrent = "pve";
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
            print("SayKarma: Now the Tab key is for pve mode. Use \"Tab\" for target the nearest enemy and \"Shift+Tab\" for target the nearest enemy player");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            print("SayKarma: Désormais la touche Tabulation est en mode pve. Utiliser \"Tab\" pour cibler l\'ennemi le plus proche et \"Shift+Tab\" pour cibler le joueur ennemi le plus proche.");
        end
    end
end

-- try to set the tab key based on your current zone
function SayKarmaExtraSetTabAuto()
  local name, type = GetInstanceInfo();
  local mapAreaId = GetCurrentMapAreaID();
  
  -- pvp mode                  | 732 = tol barad | 1064 = Mogu Island Daily Area (Isle of Thunder) | 1191 = Ashran |
  if (type == "pvp" or type == "arena" or mapAreaId == 732 or mapAreaId == 1064 or mapAreaId == 1191) then

    if (SayKarmaTabCurrent == nil) then
      SayKarmaExtraSetTabPvp();
    end -- if (SayKarmaTabCurrent == nil) then
    
    if (SayKarmaTabCurrent == "pve") then
      SayKarmaExtraSetTabPvp();
    end -- if (SayKarmaTabCurrent == "pve") then
        
  end -- if (type == "pvp" or type == "arena" or mapAreaId == 732 or mapAreaId == 1064 or mapAreaId == 1191) then
  
  -- pve mode
  if (type == "none" or type == "party" or type == "raid" or type =="scenario") then
    
    if (SayKarmaTabCurrent == nil) then
      SayKarmaExtraSetTabPve();
    end -- if (SayKarmaTabCurrent == nil) then
    
    if (SayKarmaTabCurrent == "pvp") then
      SayKarmaExtraSetTabPve();
    end -- if (SayKarmaTabCurrent == "pvp") then
    
  end -- if (type == "none" or type == "party" or type == "raid" or type =="scenario") then
end


-- announce to your mates what happened to you
function SayKarmaAnnounce(whatHappened, whichClass, fromWho, whichSpell)
    local SKwhat  = whatHappened;       -- string Value: "Stunned" || "Silenced" || "Hex" || "Polymorph"
    local SKclass = whichClass;         -- string Value: "dk" || "druid" || "Hunter" ||
    local SKwho   = fromWho;            -- string Value: "name"
    local SKspell = whichSpell;         -- string Value: "[Spell]"
    --local SKdeco;
    
    --if (SayKarmaPrefs['WhichDecoration'] == "Skull") then
    --    SKdeco = "{rt8}";
    --end
    
    if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
        if (SKclass == "dk") then SKclass = "dk"; end
        if (SKclass == "druid") then SKclass = "druide"; end
        if (SKclass == "hunt") then SKclass = "chasseur"; end
        if (SKclass == "mage") then SKclass = "mage"; end
        if (SKclass == "monk") then SKclass = "moine"; end
        if (SKclass == "paladin") then SKclass = "paladin"; end
        if (SKclass == "priest") then SKclass = "prêtre"; end
        if (SKclass == "rogue") then SKclass = "voleur"; end
        if (SKclass == "shaman") then SKclass = "chaman"; end
        if (SKclass == "warlock") then SKclass = "démoniste"; end
        if (SKclass == "war") then SKclass = "guerrier"; end
    end
    
    
    if (SKwhat == "Stunned"
        or SKwhat == "Silenced"
        or SKwhat == "Feared"
        or SKwhat == "Sapped"
        or SKwhat == "Disoriented"
        ) then
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
            SendChatMessage("{rt8} ".. SKwhat .." by this ".. SKclass .." -> " .. SKwho .." with: ".. SKspell .." ! {rt8}","SAY");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            SendChatMessage("{rt8} ".. SKwhat .." par ce ".. SKclass .." -> " .. SKwho .." avec le sort: ".. SKspell .." ! {rt8}","SAY");
        end
        return
      
    -- 3 -> Polymorph/hex/Cyclone
    elseif (SKwhat == 3) then
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
            SendChatMessage("{rt8} ".. SKspell .." on me, by this ".. SKclass .." -> " .. SKwho .." ! {rt8}","SAY");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            SendChatMessage("{rt8} ".. SKspell .." sur moi, par ce ".. SKclass .." -> " .. SKwho .." ! {rt8}","SAY");
        end
        
        return
        
    -- 4 -> Succubus warlock
    elseif (SKwhat == 4) then
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then            
            SendChatMessage("{rt8} ".. SKspell .." on me, cc that succubus asap ! {rt8}","SAY");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            SendChatMessage("{rt8} ".. SKspell .." sur moi, cc/kick la succube du démoniste asap ! {rt8}","SAY");
        end
        
        return
        
    -- default -> ERROR
    else        -- Just in case
        if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
            print("SayKarma Error: Value unknown for this variable -> SKwhat");
        end
        
        if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
            print("SayKarma Erreur: Valeur inconnue pour la variable -> SKwhat");
        end
    end
    
end -- End of SayKarmaAnnounce()

-- old announce function for "touch of karma"
function SayKarmaAnnounceTouched(fromWho, whichSpell)
    local SKwho   = fromWho;            -- string Value: "name"
    local SKspell = whichSpell;         -- string Value: "[Spell]"
    
    if (SayKarmaPrefs['SayKarmaLanguage'] == "en") then
        SendChatMessage("{rt8} ".. SKspell .." on me (10s). Stop dps this monk -> ".. SKwho .." ! {rt8}","SAY");
    end
    
    if (SayKarmaPrefs['SayKarmaLanguage'] == "fr") then
        SendChatMessage("{rt8} ".. SKspell .." sur moi (10s). Arrêtez d'attaquer ce moine -> ".. SKwho .." ! {rt8}","SAY");
    end
    
    return
end -- End of SayKarmaAnnounceTouched()


SayKarmaCommand:SetScript("OnEvent", SayKarmaCommand.OnEvent);
